@@ -6,7 +6,7 @@ from os.path import expanduser
 
 import requests
 
-from metaappscriptsdk.exceptions import UnexpectedResponseError, DbQueryError, ServerError
+from metaappscriptsdk.exceptions import UnexpectedError, DbQueryError, ServerError
 from metaappscriptsdk.logger import create_logger, eprint
 from metaappscriptsdk.logger.bulk_logger import BulkLogger
 from metaappscriptsdk.logger.logger import Logger
@@ -91,7 +91,7 @@ class MetaApp(object):
         service_id = os.environ.get('SERVICE_ID', "local_debug_serivce")
         self.build_num = os.environ.get('BUILD_NUM', '0')
         self.service_id = service_id
-        create_logger(service_id=service_id, service_ns=service_ns, gcloud_log_host_port=gcloud_log_host_port, debug=self.debug)
+        create_logger(service_id=service_id, service_ns=service_ns, build_num=self.build_num, gcloud_log_host_port=gcloud_log_host_port, debug=self.debug)
 
         self.__read_developer_settings()
 
@@ -205,7 +205,7 @@ class MetaApp(object):
                         if 'details' in decoded_resp['error']:
                             eprint(decoded_resp['error']['details'])
                         raise DbQueryError(decoded_resp['error'])
-                    raise UnexpectedResponseError()
+                    raise UnexpectedError()
                 else:
                     process_meta_api_error_code(resp.status_code, request, resp.text)
             except (requests.exceptions.ConnectionError, ConnectionError, TimeoutError) as e:
